@@ -694,16 +694,16 @@ class AboutDialog(QDialog, Ui_AboutDialog):
         """
         screenGeometry = QApplication.desktop().screenGeometry()
         if screenGeometry.height() > screenGeometry.width():
-            self.resize(480, 260)
+            self.resize(480, 340)
             self.label_3.setGeometry(QRect(10, 140, 371, 30))
             self.websiteButton.setGeometry(QRect(10, 180, 460, 70))
-            #self.bugButton.setGeometry(QRect(10, 260, 460, 70))
+            self.donateButton.setGeometry(QRect(10, 260, 460, 70))
             self.textEdit.setGeometry(QRect(130, 40, 360, 95))
         else:   
             self.resize(800, 190)
             self.label_3.setGeometry(QRect(10, 155, 371, 30))
-            self.websiteButton.setGeometry(QRect(640, 110, 150, 70))
-            #self.bugButton.setGeometry(QRect(640, 110, 150, 70))
+            self.websiteButton.setGeometry(QRect(640, 30, 150, 70))
+            self.donateButton.setGeometry(QRect(640, 110, 150, 70))
             self.textEdit.setGeometry(QRect(130, 40, 400, 100))            
     
     @pyqtSignature("")
@@ -714,13 +714,13 @@ class AboutDialog(QDialog, Ui_AboutDialog):
         os.system("dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:'http://marxianthecoder.blogspot.com'")
         self.close()
     
-#    @pyqtSignature("")
-#    def on_bugButton_clicked(self):
-#        """
-#        Slot documentation goes here.
-#        """
-        # TODO: not implemented yet
-#        self.close()
+    @pyqtSignature("")
+    def on_donateButton_clicked(self):
+        """
+        Slot documentation goes here.
+        """
+        os.system("dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:'https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=stuhowarth77%40gmail%2ecom&lc=GB&item_name=cuteTube&currency_code=USD&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted'")
+        self.close()
 
 class SwitchAccountDialog(QDialog, Ui_SwitchAccountDialog):
     """
