@@ -181,14 +181,16 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
                 QMaemo5InformationBox.information(self, "Unable to connect to YouTube, please try again")
             except:
                 pass
-                
-    @pyqtSignature("")
-    def on_actionMoreResults_triggered(self):
+
+        
+    def getMoreResults(self, scrollBarPos):
         """
-        Obtains a further 25 results from the video feed.
+        Appends more results to the list when the user scrolls 
+        to the end of the existing results.
         """
-        self.loadData()
-        self.toggleBusy(True)
+        if scrollBarPos > self.minScrollPos and scrollBarPos > (self.results - 10) * 79:
+            self.minScrollPos = scrollBarPos
+            self.loadData()
 
     def reloadData(self):
         """
@@ -205,6 +207,8 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         item = QListWidgetItem()
         item.setSizeHint(size)
         itemWidget = customwidgets.VideoItemWidget(videoData[0], videoData[1])
+        if self.actionPencil.isChecked():
+            itemWidget.showCheckBox()
         self.listWidget.addItem(item)
         self.listWidget.setItemWidget(item, itemWidget)
         title = itemWidget.titleLabel.text()
@@ -425,13 +429,15 @@ class MostRecentWindow(CutetubeWindows):
         self.actionPencil.setVisible(True)
         self.pencilList = []
         self.results = 0
+        self.minScrollPos = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/standardfeeds/most_recent"
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
-        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)        
+        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)   
+        self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
         self.loadData()
-        self.toggleBusy(True)
+        
 
 class MostViewedWindow(CutetubeWindows):
     """
@@ -449,13 +455,14 @@ class MostViewedWindow(CutetubeWindows):
         self.actionPencil.setVisible(True)
         self.pencilList = []
         self.results = 0
+        self.minScrollPos = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/standardfeeds/most_viewed?time=today"
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
         self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)        
+        self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
         self.loadData()
-        self.toggleBusy(True)
         
 class SearchResultsWindow(CutetubeWindows):
     """
@@ -475,6 +482,7 @@ class SearchResultsWindow(CutetubeWindows):
         self.searchString = searchString
         self.pencilList = []
         self.results = 0
+        self.minScrollPos = 0
         self.info = False
         self.show() 
         searchTerms = self.searchString.replace(" ", "+")
@@ -485,9 +493,9 @@ class SearchResultsWindow(CutetubeWindows):
             self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?author=%s&vq=%s&orderby=%s" % (username, searchTerms, searchOrder)
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
-        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusyandCheckResults)        
+        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusyandCheckResults)       
+        self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults) 
         self.loadData()
-        self.toggleBusy(True)
 
     def addVideo(self, videoData):
         """
@@ -499,6 +507,8 @@ class SearchResultsWindow(CutetubeWindows):
         item = QListWidgetItem()
         item.setSizeHint(size)
         itemWidget = customwidgets.VideoItemWidget(videoData[0], videoData[1])
+        if self.actionPencil.isChecked():
+            itemWidget.showCheckBox()
         self.listWidget.addItem(item)
         self.listWidget.setItemWidget(item, itemWidget)
         title = itemWidget.titleLabel.text()
@@ -539,13 +549,14 @@ class UploadsWindow(CutetubeWindows):
         self.actionPencil.setVisible(True)
         self.pencilList = []
         self.results = 0
+        self.minScrollPos = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/users/default/uploads"
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
-        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)        
+        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)  
+        self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)      
         self.loadData()
-        self.toggleBusy(True)
         
     @pyqtSignature("")
     def on_actionSearch_triggered(self):
@@ -577,13 +588,14 @@ class UserWindow(CutetubeWindows):
         self.actionPencil.setVisible(True)
         self.pencilList = []
         self.results = 0
+        self.minScrollPos = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/users/%s/uploads" % self.username
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
-        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)        
+        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)
+        self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
         self.loadData()
-        self.toggleBusy(True)
         
     @pyqtSignature("")
     def on_actionSearch_triggered(self):
@@ -609,13 +621,14 @@ class RelatedVideosWindow(CutetubeWindows):
         self.video = video
         self.pencilList = []
         self.results = 0
+        self.minScrollPos = 0
         self.show()
         self.videoFeed = video.link[4].href
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
         self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)        
+        self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
         self.loadData(self.video.media.title.text)
-        self.toggleBusy(True)
 
     def loadData(self):
         try:
@@ -644,13 +657,14 @@ class FavouritesWindow(CutetubeWindows):
         self.connect(self.actionRemoveFromFavourites, SIGNAL("triggered()"), self.removeFromFavourites)        
         self.pencilList = []
         self.results = 0
+        self.minScrollPos = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/users/default/favorites"
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
-        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)        
+        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy) 
+        self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
         self.loadData()
-        self.toggleBusy(True)
 
     def removeFromFavourites(self):
         row = self.listWidget.currentRow()
@@ -677,7 +691,6 @@ class PlaylistsWindow(CutetubeWindows):
 #        self.actionPlayPlaylist2.setVisible(True)
         self.actionEditPlaylist.setVisible(True)
         self.actionDeletePlaylist.setVisible(True)
-        self.actionMoreResults.setVisible(False)
         self.connect(self.actionEditPlaylist, SIGNAL("triggered()"), self.editPlaylist)
         self.connect(self.actionDeletePlaylist, SIGNAL("triggered()"), self.deletePlaylist)
 #        self.connect(self.actionPlayPlaylist2, SIGNAL("triggered()"), self.playPlaylist)
@@ -809,13 +822,14 @@ class PlaylistVideosWindow(CutetubeWindows):
         self.connect(self.actionRemoveFromPlaylist, SIGNAL("triggered()"), self.removeFromPlaylist)
         self.pencilList = []
         self.results = 0
+        self.minScrollPos = 0
         self.show()
         self.videoFeed = "http://gdata.youtube.com/feeds/api/playlists/%s" % playlistId.split("/")[-1]
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
-        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)        
+        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)
+        self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
         self.loadData()
-        self.toggleBusy(True)
 
     def editVideo(self):
         row = self.listWidget.currentRow()
@@ -926,7 +940,6 @@ class PlaybackQueueWindow(CutetubeWindows):
         self.actionAddToPlaylist.setVisible(True)
         self.actionRemoveFromQueue.setVisible(True)
         self.actionGoToQueue.setVisible(False)
-        self.actionMoreResults.setVisible(False)
         self.connect(self.actionRemoveFromQueue, SIGNAL("triggered()"), self.removeFromQueue)
         self.show()
         self.yt = youtubeservice.YouTubeQueueFeed(self)
@@ -1053,7 +1066,6 @@ class SubscriptionsWindow(CutetubeWindows):
         self.setWindowTitle("My Subscriptions")
         self.actionUnsubscribe.setVisible(True)
         self.actionNewSubscriptionVideos.setVisible(True)
-        self.actionMoreResults.setVisible(False)
         self.connect(self.actionUnsubscribe, SIGNAL("triggered()"), self.removeSubscription)
         self.show()
         self.yt = youtubeservice.YouTubeSubscriptionsFeed(self)
@@ -1146,6 +1158,7 @@ class NewSubscriptionVideosWindow(CutetubeWindows):
         self.actionPencil.setVisible(True)
         self.pencilList = []
         self.results = 0
+        self.minScrollPos = 0
         self.show()
         try:
             QMaemo5InformationBox.information(self, "Showing latest videos from your subscriptions")
@@ -1154,9 +1167,9 @@ class NewSubscriptionVideosWindow(CutetubeWindows):
         self.videoFeed = "http://gdata.youtube.com/feeds/api/users/default/newsubscriptionvideos"
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
-        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)        
+        self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy) 
+        self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
         self.loadData()
-        self.toggleBusy(True)
 
 class DownloadsWindow(CutetubeWindows):
     """
@@ -1178,7 +1191,6 @@ class DownloadsWindow(CutetubeWindows):
         self.actionGoToQueue.setVisible(False)
         self.actionResumeDownloads.setVisible(True)
         self.actionPauseDownloads.setVisible(True)
-        self.actionMoreResults.setVisible(False)
         self.connect(self.actionRemoveFromQueue,  SIGNAL("triggered()"),  self.cancelDownload)
         self.connect(self.actionPauseDownload,  SIGNAL("triggered()"),  self.pauseDownload)
         self.connect(self.actionResumeDownload,  SIGNAL("triggered()"),  self.resumeDownload)
@@ -1363,7 +1375,6 @@ class CommentsWindow(CutetubeWindows):
         self.setWindowTitle("Comments")
         self.actionAddComment.setVisible(True)
         self.actionGoToQueue.setVisible(False)
-        self.actionMoreResults.setVisible(False)
         self.show()
         self.video = video
         self.yt = youtubeservice.YouTubeCommentsFeed(self, self.video)
