@@ -212,10 +212,18 @@ class YouTubeVideoFeed(QThread):
         """
         Retrieves and returns the video feed.
         """
+        self.emit(SIGNAL("feedCompleted(bool)"), True)
         try:
             self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(self.videoFeed + "?start-index=%s" % unicode(self.results + 1))
         except:
-            self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(self.videoFeed + "&start-index=%s" % unicode(self.results + 1))
+            try:
+                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(self.videoFeed + "&start-index=%s" % unicode(self.results + 1))
+            except:
+                pass
+        self.emit(SIGNAL("feedCompleted(bool)"), False)
+            
+    def getVideoData(self):
+        self.emit(SIGNAL("feedCompleted(bool)"), True)
         for video in self.ytVideoFeed.entry:
             try:
                 thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[3].url)
@@ -228,7 +236,10 @@ class YouTubeVideoFeed(QThread):
         self.emit(SIGNAL("feedCompleted(bool)"), False)        
 
     def run(self):
-        self.getVideoFeed() 
+        if self.results == 0:
+            self.getVideoFeed() 
+        self.getVideoData()
+        self.getVideoFeed()
 
 class YouTubeQueueFeed(QThread):
     """
@@ -373,10 +384,7 @@ class YouTubeVideoPlayer(QThread):
             os.system(playbackCommand % filename.encode("utf-8"))
         else:
             videoUrl = YouTubeDataService.getVideoUrl(self.video,  YouTubeVideoPlayer.playbackFormat)
-            self.tempfile = "%s/%s.mp4.temp" % (YouTubeVideoDownloader.downloadFolder, unicode(re.sub('[:/|\\\\]', "-", self.video.media.title.text), "utf-8"))
-            downloader = DownloadURLOpener()
-            downloader.retrieve_resume(videoUrl,  tempfile)
-            os.system(playbackCommand % self.tempfile)  
+            os.system(playbackCommand % videoUrl)  
 
     def run(self):
         if self.video != None:
@@ -389,7 +397,7 @@ class YouTubeVideoDownloader(object):
     Manages download tasks in the download queue.
     """
     # Static variables
-    downloadFolder = "/home/user/MyDocs/Videos"
+    downloadFolder = "/home/user/MyDocs/.videos"
     downloadFormat = "18"
     downloadQueue = []
     taskQueue = []
@@ -700,7 +708,7 @@ class DownloadURLOpener(urllib.FancyURLopener):
     """
     This code is from download.py of gPodder.
     """
-    def __init__( self):
+    def __init__(self):
         urllib.FancyURLopener.__init__(self, None)
 
     def retrieveResume(self, url, filename, reporthook=None, data=None):
